==> polymer-networking-0.9.19+1.21.1-sources.jar: eu/pb4/polymer/networking/impl/FallbackServerPacketHandler.java <==
package eu.pb4.polymer.networking.impl;

import net.minecraft.class_2539;
import net.minecraft.class_2792;
import net.minecraft.class_2793;
import net.minecraft.class_2795;
import net.minecraft.class_2797;
import net.minecraft.class_2799;
import net.minecraft.class_2803;
import net.minecraft.class_2805;
import net.minecraft.class_2811;
import net.minecraft.class_2813;
import net.minecraft.class_2815;
import net.minecraft.class_2817;
import net.minecraft.class_2820;
import net.minecraft.class_2822;
import net.minecraft.class_2824;
import net.minecraft.class_2827;
import net.minecraft.class_2828;
import net.minecraft.class_2833;
import net.minecraft.class_2836;
import net.minecraft.class_2838;
import net.minecraft.class_2840;
import net.minecraft.class_2842;
import net.minecraft.class_2846;
import net.minecraft.class_2848;
import net.minecraft.class_2851;
import net.minecraft.class_2853;
import net.minecraft.class_2855;
import net.minecraft.class_2856;
import net.minecraft.class_2859;
import net.minecraft.class_2863;
import net.minecraft.class_2866;
import net.minecraft.class_2868;
import net.minecraft.class_2870;
import net.minecraft.class_2871;
import net.minecraft.class_2873;
import net.minecraft.class_2875;
import net.minecraft.class_2877;
import net.minecraft.class_2879;
import net.minecraft.class_2884;
import net.minecraft.class_2885;
import net.minecraft.class_2886;
import net.minecraft.class_2935;
import net.minecraft.class_3753;
import net.minecraft.class_4210;
import net.minecraft.class_4211;
import net.minecraft.class_5194;
import net.minecraft.class_5427;
import net.minecraft.class_6374;
import net.minecraft.class_7472;
import net.minecraft.class_7640;
import net.minecraft.class_7861;
import net.minecraft.class_8590;
import net.minecraft.class_8591;
import net.minecraft.class_8735;
import net.minecraft.class_8736;
import net.minecraft.class_8791;
import net.minecraft.class_8875;
import net.minecraft.class_9091;
import net.minecraft.class_9179;
import net.minecraft.class_9220;
import net.minecraft.class_9449;
import net.minecraft.class_9812;
import net.minecraft.network.packet.c2s.common.*;
import net.minecraft.network.packet.c2s.play.*;
import java.util.function.Consumer;

public record FallbackServerPacketHandler(class_2539 phase,
                                          Consumer<class_8791> optionsConsumer,
                                          Consumer<class_2817> payloadConsumer,
                                          Consumer<class_9812> disconnectionInfoConsumer
) implements class_8735, class_2792 {
    @Override
    public class_2539 method_52280() {
        return phase;
    }

    @Override
    public void method_52408(class_8736 packet) {

    }

    @Override
    public void method_56909(class_9220 packet) {

    }

    @Override
    public void method_52393(class_2827 packet) {

    }

    @Override
    public void method_52394(class_6374 packet) {

    }

    @Override
    public void method_52392(class_2817 packet) {
        this.payloadConsumer.accept(packet);
    }

    @Override
    public void method_52395(class_2856 packet) {

    }

    @Override
    public void method_12069(class_2803 packet) {
        optionsConsumer.accept(packet.comp_1963());
    }

    @Override
    public void method_55851(class_9091 packet) {

    }

    @Override
    public void method_10839(class_9812 info) {
        this.disconnectionInfoConsumer.accept(info);
    }

    @Override
    public boolean method_48106() {
        return true;
    }

    @Override
    public void method_12052(class_2879 packet) {

    }

    @Override
    public void method_12048(class_2797 packet) {

    }

    @Override
    public void method_43667(class_7472 packet) {

    }

    @Override
    public void method_58580(class_9449 packet) {

    }

    @Override
    public void method_44898(class_7640 packet) {

    }

    @Override
    public void method_12068(class_2799 packet) {

    }

    @Override
    public void method_12055(class_2811 packet) {

    }

    @Override
    public void method_12076(class_2813 packet) {

    }

    @Override
    public void method_12061(class_2840 packet) {

    }

    @Override
    public void method_12054(class_2815 packet) {

    }

    @Override
    public void method_12062(class_2824 packet) {

    }

    @Override
    public void method_12063(class_2828 packet) {

    }

    @Override
    public void method_12083(class_2842 packet) {

    }

    @Override
    public void method_12066(class_2846 packet) {

    }

    @Override
    public void method_12045(class_2848 packet) {

    }

    @Override
    public void method_12067(class_2851 packet) {

    }

    @Override
    public void method_12056(class_2868 packet) {

    }

    @Override
    public void method_12070(class_2873 packet) {

    }

    @Override
    public void method_12071(class_2877 packet) {

    }

    @Override
    public void method_12046(class_2885 packet) {

    }

    @Override
    public void method_12065(class_2886 packet) {

    }

    @Override
    public void method_12073(class_2884 packet) {

    }

    @Override
    public void method_12064(class_2836 packet) {

    }

    @Override
    public void method_12078(class_2833 packet) {

    }

    @Override
    public void method_12050(class_2793 packet) {

    }

    @Override
    public void method_12047(class_2853 packet) {

    }

    @Override
    public void method_30303(class_5427 packet) {

    }

    @Override
    public void method_12058(class_2859 packet) {

    }

    @Override
    public void method_12059(class_2805 packet) {

    }

    @Override
    public void method_12077(class_2870 packet) {

    }

    @Override
    public void method_12049(class_2871 packet) {

    }

    @Override
    public void method_12084(class_2838 packet) {

    }

    @Override
    public void method_12060(class_2855 packet) {

    }

    @Override
    public void method_12057(class_2866 packet) {

    }

    @Override
    public void method_12051(class_2875 packet) {

    }

    @Override
    public void method_12080(class_2863 packet) {

    }

    @Override
    public void method_12053(class_2820 packet) {

    }

    @Override
    public void method_12074(class_2822 packet) {

    }

    @Override
    public void method_54436(class_8875 packet) {

    }

    @Override
    public void method_12072(class_2795 packet) {

    }

    @Override
    public void method_16383(class_3753 packet) {

    }

    @Override
    public void method_27273(class_5194 packet) {

    }

    @Override
    public void method_19475(class_4210 packet) {

    }

    @Override
    public void method_19476(class_4211 packet) {

    }

    @Override
    public void method_46367(class_7861 packet) {

    }

    @Override
    public void method_52279(class_8591 packet) {

    }

    @Override
    public void method_52278(class_8590 packet) {

    }

    @Override
    public void method_56619(class_9179 packet) {

    }

    @Override
    public void method_12697(class_2935 packet) {

    }
}

==> polymer-networking-0.14.4+1.21.10-sources.jar: eu/pb4/polymer/networking/impl/FallbackServerPacketHandler.java <==
package eu.pb4.polymer.networking.impl;

import net.minecraft.class_10370;
import net.minecraft.class_10371;
import net.minecraft.class_10387;
import net.minecraft.class_10615;
import net.minecraft.class_10616;
import net.minecraft.class_11410;
import net.minecraft.class_11411;
import net.minecraft.class_11752;
import net.minecraft.class_2539;
import net.minecraft.class_2792;
import net.minecraft.class_2793;
import net.minecraft.class_2795;
import net.minecraft.class_2797;
import net.minecraft.class_2799;
import net.minecraft.class_2803;
import net.minecraft.class_2805;
import net.minecraft.class_2811;
import net.minecraft.class_2813;
import net.minecraft.class_2815;
import net.minecraft.class_2817;
import net.minecraft.class_2820;
import net.minecraft.class_2822;
import net.minecraft.class_2824;
import net.minecraft.class_2827;
import net.minecraft.class_2828;
import net.minecraft.class_2833;
import net.minecraft.class_2836;
import net.minecraft.class_2840;
import net.minecraft.class_2842;
import net.minecraft.class_2846;
import net.minecraft.class_2848;
import net.minecraft.class_2851;
import net.minecraft.class_2853;
import net.minecraft.class_2855;
import net.minecraft.class_2856;
import net.minecraft.class_2859;
import net.minecraft.class_2863;
import net.minecraft.class_2866;
import net.minecraft.class_2868;
import net.minecraft.class_2870;
import net.minecraft.class_2871;
import net.minecraft.class_2873;
import net.minecraft.class_2875;
import net.minecraft.class_2877;
import net.minecraft.class_2879;
import net.minecraft.class_2884;
import net.minecraft.class_2885;
import net.minecraft.class_2886;
import net.minecraft.class_2935;
import net.minecraft.class_3753;
import net.minecraft.class_4210;
import net.minecraft.class_4211;
import net.minecraft.class_5194;
import net.minecraft.class_5427;
import net.minecraft.class_6374;
import net.minecraft.class_7472;
import net.minecraft.class_7640;
import net.minecraft.class_7861;
import net.minecraft.class_8590;
import net.minecraft.class_8591;
import net.minecraft.class_8735;
import net.minecraft.class_8736;
import net.minecraft.class_8791;
import net.minecraft.class_8875;
import net.minecraft.class_9091;
import net.minecraft.class_9179;
import net.minecraft.class_9220;
import net.minecraft.class_9449;
import net.minecraft.class_9812;
import net.minecraft.class_9836;
import net.minecraft.class_9837;
import net.minecraft.network.packet.c2s.common.*;
import net.minecraft.network.packet.c2s.play.*;
import java.util.function.Consumer;

public record FallbackServerPacketHandler(class_2539 phase,
                                          Consumer<class_8791> optionsConsumer,
                                          Consumer<class_2817> payloadConsumer,
                                          Consumer<class_9812> disconnectionInfoConsumer
) implements class_8735, class_2792 {
    @Override
    public class_2539 method_52280() {
        return phase;
    }

    @Override
    public void method_52408(class_8736 packet) {

    }

    @Override
    public void method_56909(class_9220 packet) {

    }

    @Override
    public void method_73259(class_11752 packet) {

    }

    @Override
    public void method_52393(class_2827 packet) {

    }

    @Override
    public void method_52394(class_6374 packet) {

    }

    @Override
    public void method_52392(class_2817 packet) {
        this.payloadConsumer.accept(packet);
    }

    @Override
    public void method_52395(class_2856 packet) {

    }

    @Override
    public void method_12069(class_2803 packet) {
        optionsConsumer.accept(packet.comp_1963());
    }

    @Override
    public void method_71953(class_11411 customClickActionC2SPacket) {

    }

    @Override
    public void method_55851(class_9091 packet) {

    }

    @Override
    public void method_10839(class_9812 info) {
        this.disconnectionInfoConsumer.accept(info);
    }

    @Override
    public boolean method_48106() {
        return true;
    }

    @Override
    public void method_12052(class_2879 packet) {

    }

    @Override
    public void method_12048(class_2797 packet) {

    }

    @Override
    public void method_43667(class_7472 packet) {

    }

    @Override
    public void method_58580(class_9449 packet) {

    }

    @Override
    public void method_44898(class_7640 packet) {

    }

    @Override
    public void method_12068(class_2799 packet) {

    }

    @Override
    public void method_12055(class_2811 packet) {

    }

    @Override
    public void method_12076(class_2813 packet) {

    }

    @Override
    public void method_12061(class_2840 packet) {

    }

    @Override
    public void method_12054(class_2815 packet) {

    }

    @Override
    public void method_12062(class_2824 packet) {

    }

    @Override
    public void method_12063(class_2828 packet) {

    }

    @Override
    public void method_12083(class_2842 packet) {

    }

    @Override
    public void method_12066(class_2846 packet) {

    }

    @Override
    public void method_12045(class_2848 packet) {

    }

    @Override
    public void method_12067(class_2851 packet) {

    }

    @Override
    public void method_12056(class_2868 packet) {

    }

    @Override
    public void method_12070(class_2873 packet) {

    }

    @Override
    public void method_12071(class_2877 packet) {

    }

    @Override
    public void method_12046(class_2885 packet) {

    }

    @Override
    public void method_12065(class_2886 packet) {

    }

    @Override
    public void method_12073(class_2884 packet) {

    }

    @Override
    public void method_12064(class_2836 packet) {

    }

    @Override
    public void method_12078(class_2833 packet) {

    }

    @Override
    public void method_12050(class_2793 packet) {

    }

    @Override
    public void method_65306(class_10387 packet) {

    }

    @Override
    public void method_12047(class_2853 packet) {

    }

    @Override
    public void method_61220(class_9837 packet) {

    }

    @Override
    public void method_30303(class_5427 packet) {

    }

    @Override
    public void method_12058(class_2859 packet) {

    }

    @Override
    public void method_12059(class_2805 packet) {

    }

    @Override
    public void method_12077(class_2870 packet) {

    }

    @Override
    public void method_12049(class_2871 packet) {

    }

    @Override
    public void method_65085(class_10370 packet) {

    }

    @Override
    public void method_12084(class_10371 packet) {

    }

    @Override
    public void method_12060(class_2855 packet) {

    }

    @Override
    public void method_12057(class_2866 packet) {

    }

    @Override
    public void method_12051(class_2875 packet) {

    }

    @Override
    public void method_66581(class_10615 packet) {

    }

    @Override
    public void method_66582(class_10616 packet) {

    }

    @Override
    public void method_12080(class_2863 packet) {

    }

    @Override
    public void method_12053(class_2820 packet) {

    }

    @Override
    public void method_12074(class_2822 packet) {

    }

    @Override
    public void method_54436(class_8875 packet) {

    }

    @Override
    public void method_12072(class_2795 packet) {

    }

    @Override
    public void method_16383(class_3753 packet) {

    }

    @Override
    public void method_27273(class_5194 packet) {

    }

    @Override
    public void method_19475(class_4210 packet) {

    }

    @Override
    public void method_71675(class_11410 packet) {

    }

    @Override
    public void method_19476(class_4211 packet) {

    }

    @Override
    public void method_46367(class_7861 packet) {

    }

    @Override
    public void method_52279(class_8591 packet) {

    }

    @Override
    public void method_52278(class_8590 packet) {

    }

    @Override
    public void method_56619(class_9179 packet) {

    }

    @Override
    public void method_61219(class_9836 packet) {

    }

    @Override
    public void method_12697(class_2935 packet) {

    }
}
